#ifndef VGA_IMAGE_H
#define VGA_IMAGE_H

#include <string>
#include <iostream>
#include <fstream>
#include <iterator>
#include <algorithm>

struct VGAImage {
  static const unsigned int W = 640;
  static const unsigned int H = 480;
  static const unsigned int DIM = W*H;

  unsigned char data [DIM];
  inline VGAImage(){
    std::fill(data, data +DIM,0) ;
  }

  inline void save(const std::string & filename){
    std::ofstream os(filename.c_str());
    os << "P2" << '\n' << W << ' ' << H << '\n' << (int)*std::max_element(data,data+DIM) << '\n';
    for(unsigned int y=0;y<H;++y){
      std::copy(data+y*W, data+(y+1)*W, 
                std::ostream_iterator<unsigned int>(os," "));
      os << std::endl;
    }
  }
  
  inline void load(const std::string & filename){
    std::ifstream is(filename.c_str());
    std::string magic_key;
    unsigned int w,h, maxval ;
    is >> magic_key >> w >> h >> maxval;
    std::copy(std::istream_iterator<unsigned int>(is),
              std::istream_iterator<unsigned int>(),data);
  }
  inline unsigned char & operator()(int x, int y) { return data[x+y*W]; }
  inline const unsigned char & operator()(int x, int y) const { return data[x+y*W]; }
};
# endif
